"""
__init__.py
===========

Author: Bas van Oostveen
Home: https://bitbucket.org/trbs/stripeol/
License: BSD

"""

__docformat__ = "restructuredtext"
__version__ = "1.0"
__license__ = "BSD License"
__author__ = "Bas van Oostveen"